@@ -1,18 +1,23 @@
-use crate::{run_utils::create_deps, CONFIG, DOTDIPLO};
+use crate::{
+    command_prelude::*, run_utils::create_deps, utils::run_utils::get_dep_urls, CONFIG, DOTDIPLO,
+};
 use anyhow::Result;
 use colored::Colorize;
 use serde_json::json;
-use std::{
-    fs::{create_dir_all, write},
-    process::Command,
-};
+use std::fs::{create_dir_all, write};
+
+pub fn cli() -> App<'static> {
+    App::new("cache").about("Cache the dependencies")
+}
 
 pub fn exec() -> Result<()> {
     if let Some(dependencies) = &CONFIG.dependencies {
         create_deps(dependencies);
         if let Some(import_map) = CONFIG.import_map {
             if import_map {
-                let imports = json!({ "imports": dependencies });
+                let import_map = get_dep_urls();
+
+                let imports = json!({ "imports": import_map });
                 write(
                     format!("{}/import_map.json", &*DOTDIPLO),
                     serde_json::to_string(&imports)?,
@@ -25,23 +30,7 @@ pub fn exec() -> Result<()> {
         println!("{}", format!("{:#?}", e).red());
         return Ok(());
     }
-    let out = Command::new("deno")
-        .args(vec![
-            "cache",
-            &*format!("{}/deps.ts", &*DOTDIPLO),
-            "--quiet",
-            &*format!("--lock={}/deno-lock.json", &*DOTDIPLO),
-            "--lock-write",
-            &*format!("{}/deno-lock.json", &*DOTDIPLO),
-        ])
-        .spawn();
-    if let Err(out) = out {
-        println!("Error occured: {:#?}", out);
-        return Ok(());
-    } else if let Err(error) = out?.wait() {
-        println!("{:#?}", error);
-        return Ok(());
-    }
+
     println!("Successfully cached the dependencies");
 
     Ok(())
